@@ -104,7 +104,7 @@ public class SubsonicActivity extends AppCompatActivity implements OnItemSelecte
 	public static final int PERMISSIONS_REQUEST_WRITE_EXTERNAL_STORAGE = 1;
 	public static final int PERMISSIONS_REQUEST_LOCATION = 2;
 
-	public static final int PERMISSIONS_REQUEST_READ_PHONE_STATE = 3;
+	public static final int PERMISSIONS_REQUEST_POST_NOTIFICATIONS = 3;
 
 	private final List<Runnable> afterServiceAvailable = new ArrayList<>();
 	private boolean drawerIdle = true;
@@ -189,9 +189,16 @@ public class SubsonicActivity extends AppCompatActivity implements OnItemSelecte
 			Util.getPreferences(this).registerOnSharedPreferenceChangeListener(preferencesListener);
 		}
 
-		// To be able to stop playback during calls, we need the phone state permission.
-		if (ContextCompat.checkSelfPermission(this, permission.READ_PHONE_STATE) != PackageManager.PERMISSION_GRANTED) {
-			ActivityCompat.requestPermissions(this, new String[]{ permission.READ_PHONE_STATE }, PERMISSIONS_REQUEST_READ_PHONE_STATE);
+		// On Android versions below Q we need WRITE_EXTERNAL_STORAGE permission.
+		if (Build.VERSION.SDK_INT < Build.VERSION_CODES.Q &&
+				ContextCompat.checkSelfPermission(this, permission.WRITE_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
+			ActivityCompat.requestPermissions(this, new String[]{ permission.WRITE_EXTERNAL_STORAGE }, PERMISSIONS_REQUEST_WRITE_EXTERNAL_STORAGE);
+		}
+
+		// On Android 13+ we need the POST_NOTIFICATIONS permission to show notifications.
+		if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU &&
+				ContextCompat.checkSelfPermission(this, Manifest.permission.POST_NOTIFICATIONS) != PackageManager.PERMISSION_GRANTED) {
+			ActivityCompat.requestPermissions(this, new String[]{ Manifest.permission.POST_NOTIFICATIONS }, PERMISSIONS_REQUEST_POST_NOTIFICATIONS);
 		}
 
 		SharedPreferences prefs = Util.getPreferences(this);
@@ -251,6 +258,7 @@ public class SubsonicActivity extends AppCompatActivity implements OnItemSelecte
 					Util.toast(this, R.string.permission_external_storage_failed);
 					finish();
 				}
+				break;
 			}
 			case PERMISSIONS_REQUEST_LOCATION: {
 				// If request is cancelled, the result arrays are empty.
@@ -259,19 +267,7 @@ public class SubsonicActivity extends AppCompatActivity implements OnItemSelecte
 				} else {
 					Util.toast(this, R.string.permission_location_failed);
 				}
-			}
-
-			case PERMISSIONS_REQUEST_READ_PHONE_STATE: {
-				// If request is cancelled, the result arrays are empty.
-				if (grantResults.length > 0 && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
-
-				} else {
-					Util.toast(this, R.string.permission_phone_state_failed);
-				}
-
-				if (ContextCompat.checkSelfPermission(this, permission.WRITE_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED && Build.VERSION.SDK_INT < Build.VERSION_CODES.Q) {
-					ActivityCompat.requestPermissions(this, new String[]{ permission.WRITE_EXTERNAL_STORAGE }, PERMISSIONS_REQUEST_WRITE_EXTERNAL_STORAGE);
-				}
+				break;
 			}
 		}
 	}
@@ -314,7 +310,6 @@ public class SubsonicActivity extends AppCompatActivity implements OnItemSelecte
 	@Override
 	protected void onStart() {
 		super.onStart();
-		Util.registerMediaButtonEventReceiver(this);
 
 		// Make sure to update theme
 		if (theme != null) {
@@ -1010,15 +1005,11 @@ public class SubsonicActivity extends AppCompatActivity implements OnItemSelecte
 		fullScreen = Util.getPreferences(this).getBoolean(Constants.PREFERENCES_KEY_FULL_SCREEN, false);
 		if(fullScreen || isTv()) {
 			// Hide additional elements on higher Android versions
-			if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT) {
-				int flags = View.SYSTEM_UI_FLAG_HIDE_NAVIGATION |
-						View.SYSTEM_UI_FLAG_FULLSCREEN |
-						View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY;
+			int flags = View.SYSTEM_UI_FLAG_HIDE_NAVIGATION |
+					View.SYSTEM_UI_FLAG_FULLSCREEN |
+					View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY;
 
-				getWindow().getDecorView().setSystemUiVisibility(flags);
-			} else if(Build.VERSION.SDK_INT < Build.VERSION_CODES.ICE_CREAM_SANDWICH) {
-				getWindow().requestFeature(Window.FEATURE_NO_TITLE);
-			}
+			getWindow().getDecorView().setSystemUiVisibility(flags);
 			getWindow().addFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN);
 		}
 	}
