@@ -19,7 +19,6 @@ import github.paroj.dsub2000.adapter.MainAdapter;
 import github.paroj.dsub2000.adapter.SectionAdapter;
 import github.paroj.dsub2000.domain.ServerInfo;
 import github.paroj.dsub2000.util.Constants;
-import github.paroj.dsub2000.util.EnvironmentVariables;
 import github.paroj.dsub2000.util.FileUtil;
 import github.paroj.dsub2000.util.LoadingTask;
 import github.paroj.dsub2000.util.ProgressListener;
@@ -30,20 +29,12 @@ import github.paroj.dsub2000.service.MusicServiceFactory;
 import github.paroj.dsub2000.view.ChangeLog;
 import github.paroj.dsub2000.view.UpdateView;
 
-import java.io.BufferedReader;
-import java.io.BufferedWriter;
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.InputStreamReader;
-import java.io.OutputStream;
-import java.io.OutputStreamWriter;
-import java.net.URL;
-import java.net.URLEncoder;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
 
-import javax.net.ssl.HttpsURLConnection;
+import androidx.core.content.FileProvider;
 
 public class MainFragment extends SelectRecyclerFragment<Integer> {
 	private static final String TAG = MainFragment.class.getSimpleName();
@@ -277,15 +268,11 @@ public class MainFragment extends SelectRecyclerFragment<Integer> {
 	}
 
 	private void getLogs() {
-		if (EnvironmentVariables.PASTEBIN_DEV_KEY == null) {
-			Util.toast(context, "No PASTEBIN_DEV_KEY configured - can't upload logs");
-			return;
-		}
 		try {
 			final PackageInfo packageInfo = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
-			new LoadingTask<String>(context) {
+			new LoadingTask<ArrayList<Uri>>(context) {
 				@Override
-				protected String doInBackground() throws Throwable {
+				protected ArrayList<Uri> doInBackground() throws Throwable {
 					updateProgress("Gathering Logs");
 					File logcat = new File(context.getExternalFilesDir(null), "dsub-logcat.txt");
 					Util.delete(logcat);
@@ -309,67 +296,18 @@ public class MainFragment extends SelectRecyclerFragment<Integer> {
 						}
 					}
 
-					URL url = new URL("https://pastebin.com/api/api_post.php");
-					HttpsURLConnection urlConnection = (HttpsURLConnection) url.openConnection();
-					StringBuffer responseBuffer = new StringBuffer();
-					try {
-						urlConnection.setReadTimeout(10000);
-						urlConnection.setConnectTimeout(15000);
-						urlConnection.setRequestMethod("POST");
-						urlConnection.setDoInput(true);
-						urlConnection.setDoOutput(true);
-
-						OutputStream os = urlConnection.getOutputStream();
-						BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(os, Constants.UTF_8));
-						writer.write("api_dev_key=" + URLEncoder.encode(EnvironmentVariables.PASTEBIN_DEV_KEY, Constants.UTF_8) + "&api_option=paste&api_paste_private=1&api_paste_code=");
-
-						BufferedReader reader = null;
-						try {
-							reader = new BufferedReader(new InputStreamReader(new FileInputStream(logcat)));
-							String line;
-							while ((line = reader.readLine()) != null) {
-								writer.write(URLEncoder.encode(line + "\n", Constants.UTF_8));
-							}
-						} finally {
-							Util.close(reader);
-						}
-
-						File stacktrace = new File(context.getExternalFilesDir(null), "dsub-stacktrace.txt");
-						if(stacktrace.exists() && stacktrace.isFile()) {
-							writer.write("\n\nMost Recent Stacktrace:\n\n");
-
-							reader = null;
-							try {
-								reader = new BufferedReader(new InputStreamReader(new FileInputStream(stacktrace)));
-								String line;
-								while ((line = reader.readLine()) != null) {
-									writer.write(URLEncoder.encode(line + "\n", Constants.UTF_8));
-								}
-							} finally {
-								Util.close(reader);
-							}
-						}
-
-						writer.flush();
-						writer.close();
-						os.close();
-
-						BufferedReader in = new BufferedReader(new InputStreamReader(urlConnection.getInputStream()));
-						String inputLine;
-						while ((inputLine = in.readLine()) != null) {
-							responseBuffer.append(inputLine);
-						}
-						in.close();
-					} finally {
-						urlConnection.disconnect();
+					String authority = context.getPackageName() + ".fileprovider";
+					ArrayList<Uri> attachments = new ArrayList<>();
+					if(logcat.exists()) {
+						attachments.add(FileProvider.getUriForFile(context, authority, logcat));
 					}
 
-					String response = responseBuffer.toString();
-					if(response.indexOf("http") == 0) {
-						return response.replace("http:", "https:");
-					} else {
-						throw new Exception("Pastebin Error: " + response);
+					File stacktrace = new File(context.getExternalFilesDir(null), "dsub-stacktrace.txt");
+					if(stacktrace.exists() && stacktrace.isFile()) {
+						attachments.add(FileProvider.getUriForFile(context, authority, stacktrace));
 					}
+
+					return attachments;
 				}
 
 				@Override
@@ -379,26 +317,25 @@ public class MainFragment extends SelectRecyclerFragment<Integer> {
 				}
 
 				@Override
-				protected void done(String logcat) {
+				protected void done(ArrayList<Uri> attachments) {
 					String footer = "Android SDK: " + Build.VERSION.SDK;
 					footer += "\nDevice Model: " + Build.MODEL;
 					footer += "\nDevice Name: " + Build.MANUFACTURER + " "  + Build.PRODUCT;
 					footer += "\nROM: " + Build.DISPLAY;
-					footer += "\nLogs: " + logcat;
 					footer += "\nBuild Number: " + packageInfo.versionCode;
 
-
 					Intent selectorIntent = new Intent(Intent.ACTION_SENDTO);
 					selectorIntent.setData(Uri.parse("mailto:"));
 
-					final Intent emailIntent = new Intent(Intent.ACTION_SEND);
-					emailIntent.putExtra(Intent.EXTRA_EMAIL, new String[]{"dsub.android@gmail.com"});
+					final Intent emailIntent = new Intent(Intent.ACTION_SEND_MULTIPLE);
+					emailIntent.putExtra(Intent.EXTRA_EMAIL, new String[]{"play.dsub2000@gmail.com"});
 					emailIntent.putExtra(Intent.EXTRA_SUBJECT, "DSub " + packageInfo.versionName + " Error Logs");
 					emailIntent.putExtra(Intent.EXTRA_TEXT, "Describe the problem here\n\n\n" + footer);
-					emailIntent.setSelector( selectorIntent );
+					emailIntent.putParcelableArrayListExtra(Intent.EXTRA_STREAM, attachments);
+					emailIntent.setType("text/plain");
+					emailIntent.addFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION);
 
 					startActivity(Intent.createChooser(emailIntent, "Send log..."));
-
 				}
 			}.execute();
 		} catch(Exception e) {}
